@@ -86,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55100
 #  endif
 #endif
 
